/*
Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
The following class opens the InverterOutQ message Queue and displays 
recieved data in console.
*/





/**
 @file
*/


#include "CMsgQActive.h"
#include "e32cons.h"

_LIT(KCommonFormat2,"%S");
_LIT(KTitle , "OutputMessage");

/**
Constructor
*/
CMsgQActive::CMsgQActive(TInt aPriority):CActive(aPriority)
	{
	CActiveScheduler::Add( this );
	}


CMsgQActive* CMsgQActive::NewL(TInt aPriority)
	{
	CMsgQActive* self=new(ELeave)CMsgQActive(aPriority);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
	}

/**
Opens the global message queue so that data can be recieved.
*/
void CMsgQActive::ConstructL()
	{
	iConsole = Console::NewL(KTitle, TSize(KConsFullScreen, KConsFullScreen));
	_LIT(KWelcomeScreen,".......Words recieved from the inverter......\n");
	iConsole->Printf(KWelcomeScreen);
	
	//Open the InverterOutQ Message Queue.
	_LIT(KGlobalInverterOutQ, "InverterOutQ");
	User::LeaveIfError(iInverterOutQ.OpenGlobal(KGlobalInverterOutQ));		
	}

/**
Recieve data from the InverterOut message queue,
requests notification when there is at least one message in the queue
*/
void CMsgQActive::StartRecieving()
	{
	iInverterOutQ.NotifyDataAvailable(iStatus);
	SetActive();
	}

CMsgQActive::~CMsgQActive()
	{
	}

/**
Cancel any outstanding request when stop command is given.
*/
void CMsgQActive::DoCancel()
	{
	//Cancel any data which is present in the message Queue.
	iInverterOutQ.CancelDataAvailable();
	delete iConsole;
	}

/**
This function recieves the message from inverter and display in the console.
*/

void CMsgQActive::RunL()
	{
	// Recieve all available messages from the message queue.
	iInverterOutQ.ReceiveBlocking(imsgQData);	
	
	//Print the recieved message in the output message console.
	iConsole->Printf(KCommonFormat2,&imsgQData);
	
	_LIT(KNextLine , "\n");
	iConsole->Printf(KNextLine);
	
	// Make asynchronous request to be notified when data is available
	iInverterOutQ.NotifyDataAvailable(iStatus);
	SetActive();
	}
